hotspot/src/share/vm/adlc/formssel.hpp
changeset 22850 4e69ce7e1101
parent 22844 90f76a40ed8a
child 22872 b6902ee5bc8d
--- a/hotspot/src/share/vm/adlc/formssel.hpp	Tue Nov 19 11:53:58 2013 -0800
+++ b/hotspot/src/share/vm/adlc/formssel.hpp	Wed Nov 20 11:08:09 2013 -0800
@@ -83,7 +83,8 @@
   const char    *_cisc_reg_mask_name;
   InstructForm  *_short_branch_form;
   bool           _is_short_branch;
-  bool           _is_mach_constant;   // true if Node is a MachConstantNode
+  bool           _is_mach_constant;    // True if Node is a MachConstantNode.
+  bool           _needs_constant_base; // True if Node needs the mach_constant_base input.
   uint           _alignment;
 
 public:
@@ -262,6 +263,8 @@
 
   bool                    is_mach_constant() const { return _is_mach_constant;     }
   void                set_is_mach_constant(bool x) {        _is_mach_constant = x; }
+  bool                    needs_constant_base() const { return _needs_constant_base;     }
+  void                set_needs_constant_base(bool x) {        _needs_constant_base = x; }
 
   InstructForm       *short_branch_form() { return _short_branch_form; }
   bool                has_short_branch_form() { return _short_branch_form != NULL; }